@@ -22,7 +22,7 @@ from superlinked.framework.common.data_types import Vector
 from superlinked.framework.common.exception import InvalidStateException
 from superlinked.framework.common.interface.has_length import HasLength
 from superlinked.framework.common.interface.weighted import Weighted
-from superlinked.framework.common.schema.schema_object import SchemaObject
+from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
 from superlinked.framework.common.space.config.aggregation.aggregation_config import (
     AggregationInputT,
 )
@@ -67,7 +67,7 @@ class AggregationNode(
         wrong_length_parents = {parent for parent in self.parents if cast(HasLength, parent).length != length}
         if any(wrong_length_parents):
             lengths = {length}.union({cast(HasLength, parent).length for parent in wrong_length_parents})
-            raise InvalidStateException(f"{self.class_name} must have parents with the same length, got {lengths}")
+            raise InvalidStateException(f"{self.class_name} must have parents with the same length.", lengths=lengths)
 
     @property
     @override
@@ -103,7 +103,7 @@ class AggregationNode(
         return False
 
     @override
-    def project_parents_to_schema(self, schema: SchemaObject) -> Sequence[Node]:
+    def project_parents_to_schema(self, schema: IdSchemaObject) -> Sequence[Node]:
         if schema in self.schemas:
             return self.parents
         return []
