@@ -128,12 +128,3 @@ class Node(Generic[NodeDataT], ABC):  # pylint: disable=too-many-instance-attrib
         if dag_effect in self.dag_effects:
             return [parent for parent in self.parents if dag_effect in parent.dag_effects]
         return []
-
-    def find_ancestor(self, type_: type[Node]) -> Node[Any] | None:
-        queue = list(self.parents)
-        while queue:
-            parent = queue.pop(0)
-            if isinstance(parent, type_):
-                return parent
-            queue.extend(parent.parents)
-        return None
