@@ -29,5 +29,6 @@ class NumberEmbeddingNode(EmbeddingNode[float, float]):
         transformation_config: TransformationConfig[float, float],
         fields_for_identification: set[SchemaField],
         schema: IdSchemaObject | None = None,
+        salt: str | None = None,
     ) -> None:
-        super().__init__([parent], transformation_config, fields_for_identification, schema)
+        super().__init__([parent], transformation_config, fields_for_identification, schema, salt)
