@@ -28,5 +28,6 @@ class RecencyNode(EmbeddingNode[int, int]):
         transformation_config: TransformationConfig[int, int],
         fields_for_identification: set[SchemaField],
         schema: IdSchemaObject | None = None,
+        salt: str | None = None,
     ) -> None:
-        super().__init__([parent], transformation_config, fields_for_identification, schema)
+        super().__init__([parent], transformation_config, fields_for_identification, schema, salt)
