@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import base64
 from dataclasses import dataclass
 
 from superlinked.framework.common.exception import InvalidInputException
@@ -32,5 +33,5 @@ class BlobInformation:
         if self.path is not None:
             return_value = self.path
         elif self.data is not None:
-            return_value = self.data.decode("utf-8")
+            return_value = base64.b64encode(self.data).decode("utf-8")
         return return_value
