@@ -44,7 +44,7 @@ SFT = TypeVar("SFT", bound=PythonTypes)
 
 class SchemaField(ComparisonOperand, Generic[SFT]):
     """
-    A SchemaField is a generic field of your `@schema` decorated class.
+    A SchemaField is a generic field of your `Schema` child class.
 
     `SchemaField`s are the basic building block for inputs that will be referenced in an embedding space.
     Sub-types of a `SchemaField` are typed data representations that you can use to transform and load data
@@ -88,9 +88,6 @@ class SchemaField(ComparisonOperand, Generic[SFT]):
         return not SchemaField._built_in_equal(left_operand, right_operand)
 
 
-SchemaFieldT = TypeVar("SchemaFieldT", bound=SchemaField)
-
-
 class String(SchemaField[str]):
     """
     Field of a schema that represents a string value.
@@ -278,4 +275,3 @@ class DescribedBlob:
 
 
 ConcreteSchemaField = String | Timestamp | Float | Integer | Boolean | FloatList | StringList | Blob
-ConcreteSchemaFieldT = TypeVar("ConcreteSchemaFieldT", bound="ConcreteSchemaField")
