@@ -28,6 +28,7 @@ logger = structlog.getLogger()
 
 YAML_FILENAME = "config.yaml"
 FRAMEWORK_SECTION = "framework"
+IMAGE_SECTION = "image"
 RESOURCE_SECTION = "resource"
 
 
@@ -54,7 +55,11 @@ class Settings(YamlBasedSettings):
     APP_ID: str = "default"
     # Embedding specific settings
     ENABLE_MPS: bool = False
-    SUPERLINKED_RESIZE_IMAGES: bool = False
+    # Batching specific settings
+    BATCHED_EMBEDDING_WAIT_TIME_MS: int = 0
+    BATCHED_VDB_READ_WAIT_TIME_MS: int = 0
+    BATCHED_BLOB_LOAD_WAIT_TIME_MS: int = 0
+    BATCHED_VDB_WRITE_WAIT_TIME_MS: int = 0
     # Embedding specific settings - model
     MODEL_WARMUP: bool = False
     MODEL_CACHE_DIR: str | None = None
@@ -67,7 +72,6 @@ class Settings(YamlBasedSettings):
     BLOB_HANDLER_MODULE_PATH: str | None = None
     BLOB_HANDLER_CLASS_NAME: str | None = None
     BLOB_HANDLER_CLASS_ARGS: dict[str, Any] | None = None
-    REQUEST_TIMEOUT: int = 600  # 10min
     # Logging specific params
     SUPERLINKED_LOG_LEVEL: int | str | None = None
     SUPERLINKED_LOG_AS_JSON: bool = False
@@ -77,11 +81,9 @@ class Settings(YamlBasedSettings):
     # DAG visualization
     ENABLE_DAG_VISUALIZATION: bool = False
     DAG_VISUALIZATION_OUTPUT_DIR: str | None = None
-
-    """Online settings"""
+    # Online settings
     ONLINE_PUT_CHUNK_SIZE: int = 10000
-
-    """Query settings"""
+    # Query settings
     QUERY_TO_RETURN_ORIGIN_ID: bool = False
     # NLQ specific params
     SUPERLINKED_NLQ_MAX_RETRIES: int = 3
@@ -110,6 +112,17 @@ class Settings(YamlBasedSettings):
             )
 
 
+class ImageSettings(YamlBasedSettings):
+    RESIZE_IMAGE_WIDTH: int = 224
+    RESIZE_IMAGE_HEIGHT: int = 224
+    IMAGE_FORMAT: str = "WebP"
+    IMAGE_QUALITY: int = 95
+
+    model_config = SettingsConfigDict(
+        yaml_file=YAML_FILENAME, yaml_config_section=IMAGE_SECTION, extra="ignore", frozen=True
+    )
+
+
 class ExternalMessageBusSettings(BaseModel):
     QUEUE_MODULE_PATH: str | None = None
     QUEUE_CLASS_NAME: str | None = None
@@ -159,6 +172,7 @@ class ResourceSettings(YamlBasedSettings):
 
 
 settings = Settings(_env_nested_delimiter="__")
+image_settings = ImageSettings(_env_nested_delimiter="__")
 resource_settings = ResourceSettings(_env_nested_delimiter="__")
 
 __all__ = ["settings", "resource_settings"]
