@@ -14,14 +14,12 @@
 
 
 from beartype.typing import Sequence
-from PIL.Image import Image as PILImage
 from typing_extensions import override
 
 from superlinked.framework.common.dag.context import ExecutionContext
 from superlinked.framework.common.data_types import Vector
 from superlinked.framework.common.interface.weighted import Weighted
 from superlinked.framework.common.schema.image_data import ImageData
-from superlinked.framework.common.settings import settings
 from superlinked.framework.common.space.aggregation.aggregation import VectorAggregation
 from superlinked.framework.common.space.config.aggregation.aggregation_config import (
     VectorAggregationConfig,
@@ -32,13 +30,13 @@ from superlinked.framework.common.space.config.embedding.image_embedding_config
 from superlinked.framework.common.space.embedding.model_based.model_embedding import (
     ModelEmbedding,
 )
-from superlinked.framework.common.util.image_util import ImageUtil
 
 
 class ImageEmbedding(ModelEmbedding[ImageData, ImageEmbeddingConfig]):
     @override
     async def embed_multiple(self, inputs: Sequence[ImageData], context: ExecutionContext) -> list[Vector]:
-        images, descriptions = self._prepare_images_and_descriptions(inputs)
+        images = [input_.image for input_ in inputs]
+        descriptions = [input_.description for input_ in inputs]
         valid_inputs = [inp for inp in (images + descriptions) if inp is not None]
         if not valid_inputs:
             return [self._config.default_vector] * len(inputs)
@@ -67,12 +65,3 @@ class ImageEmbedding(ModelEmbedding[ImageData, ImageEmbeddingConfig]):
             for image_embedding, description_embedding in zip(embeddings[: len(inputs)], embeddings[len(inputs) :])
         ]
         return combined_embeddings
-
-    def _prepare_images_and_descriptions(
-        self, inputs: Sequence[ImageData]
-    ) -> tuple[list[PILImage | None], list[str | None]]:
-        images = [input_.image for input_ in inputs]
-        descriptions = [input_.description for input_ in inputs]
-        if settings.SUPERLINKED_RESIZE_IMAGES:
-            images = [ImageUtil.resize_for_embedding(image) if image is not None else None for image in images]
-        return images, descriptions
