@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from types import NoneType
+
 from beartype.typing import Any, Sequence, cast
 
 from superlinked.framework.common.data_types import NodeDataTypes, Vector
@@ -59,7 +61,7 @@ FIELD_DATA_TYPE_BY_NODE_DATA_TYPE: dict[type[NodeDataTypes | dict], FieldDataTyp
     BlobInformation: FieldDataType.BLOB,
 }
 
-VALID_TYPE_BY_FIELD_DATA_TYPE: dict[FieldDataType, Sequence[type[NodeDataTypes | dict]]] = {
+VALID_TYPE_BY_FIELD_DATA_TYPE: dict[FieldDataType, Sequence[type[NodeDataTypes | dict | None]]] = {
     FieldDataType.BLOB: [BlobInformation],
     FieldDataType.DOUBLE: [int, float],
     FieldDataType.INT: [int],
@@ -71,6 +73,7 @@ VALID_TYPE_BY_FIELD_DATA_TYPE: dict[FieldDataType, Sequence[type[NodeDataTypes |
     FieldDataType.METADATA_STRING: [str],
     FieldDataType.VECTOR: [Vector],
     FieldDataType.IMAGE_DATA: [ImageData],
+    FieldDataType.NULL: [NoneType],
 }
 
 
@@ -83,13 +86,13 @@ class FieldTypeConverter:
             cast(type[ConcreteSchemaField], schema_field_cls)
         ):
             return field_data_type
-        raise NotImplementedException(f"Unknown schema field type: {schema_field_cls.__name__}")
+        raise NotImplementedException("Unsupported schema field type.", schema_field_type=schema_field_cls.__name__)
 
     @staticmethod
     def convert_node_data_type(type_: type[NodeDataTypes]) -> FieldDataType:
         if field_data_type := FIELD_DATA_TYPE_BY_NODE_DATA_TYPE.get(cast(type[NodeDataTypes], type_)):
             return field_data_type
-        raise NotImplementedException(f"Unknown python type: {type_}")
+        raise NotImplementedException("Unknown python type.", type_name=type_.__name__)
 
     @staticmethod
     def get_valid_node_data_types(
