@@ -20,7 +20,6 @@ from superlinked.framework.common.parser.parsed_schema import (
     ParsedSchema,
     ParsedSchemaField,
 )
-from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
 from superlinked.framework.common.schema.schema_object import SchemaField
 from superlinked.framework.common.storage.entity.entity import Entity
 from superlinked.framework.common.storage.entity.entity_data import EntityData
@@ -35,11 +34,7 @@ from superlinked.framework.common.storage_manager.storage_naming import StorageN
 
 
 class EntityBuilder:
-    def __init__(
-        self,
-        storage_naming: StorageNaming,
-    ) -> None:
-        self._storage_naming = storage_naming
+    def __init__(self) -> None:
         self._admin_fields = AdminFields()
 
     def compose_entity_id(self, schema_id: str, object_id: str) -> EntityId:
@@ -51,7 +46,7 @@ class EntityBuilder:
     def convert_schema_field_to_field(self, schema_field: SchemaField) -> Field:
         return Field(
             FieldTypeConverter.convert_schema_field_type(type(schema_field)),
-            self._storage_naming.generate_field_name_from_schema_field(schema_field),
+            StorageNaming.generate_field_name_from_schema_field(schema_field),
         )
 
     def convert_parsed_schema_field_to_field_data(self, parsed_schema_field: ParsedSchemaField) -> FieldData:
@@ -103,26 +98,11 @@ class EntityBuilder:
             schema_field_by_field_name[schema_field_data.name], schema_field_data.value
         )
 
-    def parse_entity_data(
-        self,
-        schema: IdSchemaObject,
-        entity_data: EntityData,
-        schema_field_by_field_name: dict[str, SchemaField],
-    ) -> ParsedSchema:
-        return ParsedSchema(
-            schema,
-            entity_data.id_.object_id,
-            [
-                self.parse_schema_field_data(field_data, schema_field_by_field_name)
-                for field_data in entity_data.field_data.values()
-            ],
-        )
-
     def compose_field_from_node_data_descriptor(
         self, node_id: str, node_data_key: str, node_data_type: type[PythonTypes]
     ) -> Field:
         return self.compose_field(
-            self._storage_naming.generate_node_data_field_name(node_id, node_data_key),
+            StorageNaming.generate_node_data_field_name(node_id, node_data_key),
             node_data_type,
         )
 
@@ -147,7 +127,7 @@ class EntityBuilder:
         return [
             FieldData(
                 FieldTypeConverter.convert_node_data_type(type(value)),
-                self._storage_naming.generate_node_data_field_name(node_id, key),
+                StorageNaming.generate_node_data_field_name(node_id, key),
                 value,
             )
             for key, value in node_data.items()
