@@ -34,7 +34,7 @@ class CompiledNodeRegistry(Generic[CompiledNodeT]):
 
     def __new__(cls, *_: Any) -> CompiledNodeRegistry[CompiledNodeT]:
         if cls._instance is None:
-            cls._instance = super(CompiledNodeRegistry, cls).__new__(cls)
+            cls._instance = super().__new__(cls)
         return cls._instance
 
     def __init__(
