@@ -55,6 +55,7 @@ class CustomSpace(Space[Vector, Vector], HasSpaceFieldSet):
         vector: FloatList | None | Sequence[FloatList | None],
         length: int,
         description: str | None = None,
+        salt: str | None = None,
     ) -> None:
         """
         Initializes a CustomSpace for vector storage and manipulation within Superlinked.
@@ -67,12 +68,15 @@ class CustomSpace(Space[Vector, Vector], HasSpaceFieldSet):
               This can be a single FloatList SchemaField or a list of those.
             length (int): The fixed length that all vectors in this space must have. This ensures uniformity and
               consistency in vector operations.
+            description: (str | None, optional): The description provided with NLQ to provide more accurate results.
+            salt: (str | None, optional): Enables the creation of identical spaces to allow
+                different weighted event definitions with them.
         """
         non_none_vector = self._fields_to_non_none_sequence(vector)
-        super().__init__(non_none_vector, FloatList)
+        super().__init__(non_none_vector, FloatList, salt)
         self.vector = SpaceFieldSet[list[float]](self, set(non_none_vector), allowed_param_types=[list[float]])
         self._transformation_config = self._init_transformation_config(length)
-        self._schema_node_map = self._calculate_schema_node_map(self._transformation_config)
+        self._schema_node_map = self._calculate_schema_node_map(self._transformation_config, salt)
         self._description = description
         self._length = length
 
@@ -117,13 +121,14 @@ class CustomSpace(Space[Vector, Vector], HasSpaceFieldSet):
         return CustomVectorEmbeddingNode(None, self.transformation_config, self.vector.fields, schema)
 
     def _calculate_schema_node_map(
-        self, transformation_config: TransformationConfig
+        self, transformation_config: TransformationConfig, salt: str | None
     ) -> dict[IdSchemaObject, EmbeddingNode[Vector, Vector]]:
         unchecked_custom_node_map = {
             vector_schema_field: CustomVectorEmbeddingNode(
                 parent=SchemaFieldNode(vector_schema_field),
                 transformation_config=transformation_config,
                 fields_for_identification=self.vector.fields,
+                salt=salt,
             )
             for vector_schema_field in self.vector.fields
         }
