@@ -51,25 +51,6 @@ class NumberSpace(Space[float, float], HasSpaceFieldSet):
     The preference can be controlled by the mode parameter.
 
     Note: In similar mode you MUST add a similar clause to the query or it will raise.
-
-    Attributes:
-        number (SpaceFieldSet): A set of Number objects.
-            It is a SchemaFieldObject not regular python ints or floats.
-        min_value (float | int): This represents the minimum boundary. Any number lower than
-            this will be considered as this minimum value. It can be either a float or an integer.
-            It must larger or equal to 0 in case of scale=LogarithmicScale(base).
-        max_value (float | int): This represents the maximum boundary. Any number higher than
-            this will be considered as this maximum value. It can be either a float or an integer.
-            It cannot be 0 in case of scale=LogarithmicScale(base).
-        mode (Mode): The mode of the number embedding. Possible values are: maximum, minimum and similar.
-            Similar mode expects a .similar on the query, otherwise it will default to maximum.
-        scale (Scale): The scaling of the number embedding.
-            Possible values are: LinearScale(), and LogarithmicScale(base).
-            LogarithmicScale base must be larger than 1. It defaults to LinearScale().
-        aggregation_mode (InputAggregationMode): The  aggregation mode of the number embedding.
-            Possible values are: maximum, minimum and average.
-        negative_filter (float): This is a value that will be set for everything that is equal or
-            lower than the min_value. It can be a float. It defaults to 0 (No effect)
     """
 
     def __init__(  # pylint: disable=too-many-arguments
@@ -81,6 +62,7 @@ class NumberSpace(Space[float, float], HasSpaceFieldSet):
         scale: Scale = LinearScale(),
         aggregation_mode: InputAggregationMode = InputAggregationMode.INPUT_AVERAGE,
         negative_filter: float = 0.0,
+        salt: str | None = None,
     ) -> None:
         """
         Initializes the NumberSpace object.
@@ -103,17 +85,14 @@ class NumberSpace(Space[float, float], HasSpaceFieldSet):
                 Possible values are: maximum, minimum and average.
             negative_filter (float): This is a value that will be set for everything that is equal or
                 lower than the min_value. It can be a float. It defaults to 0 (No effect)
+            salt: (str | None, optional): Enables the creation of identical spaces to allow
+                different weighted event definitions with them.
         """
         non_none_number = self._fields_to_non_none_sequence(number)
         self._embedding_config = NumberEmbeddingConfig(
-            float,
-            float(min_value),
-            float(max_value),
-            mode,
-            scale,
-            negative_filter,
+            float, float(min_value), float(max_value), mode, scale, negative_filter
         )
-        super().__init__(non_none_number, Number)
+        super().__init__(non_none_number, Number, salt)
         number_fields = non_none_number
         self.number = SpaceFieldSet[float](self, set(number_fields))
         self._aggregation_config_type_by_mode = self.__init_aggregation_config_type_by_mode()
@@ -123,6 +102,7 @@ class NumberSpace(Space[float, float], HasSpaceFieldSet):
                 parent=SchemaFieldNode(number_field),
                 transformation_config=self._transformation_config,
                 fields_for_identification=self.number.fields,
+                salt=salt,
             )
             for number_field in number_fields
         }
