@@ -37,7 +37,7 @@ from superlinked.framework.online.online_entity_cache import OnlineEntityCache
 
 class DefaultOnlineNode(OnlineNode[NT, NodeDataT], ABC, Generic[NT, NodeDataT]):
     @override
-    def evaluate_self(
+    async def evaluate_self(
         self,
         parsed_schemas: Sequence[ParsedSchema],
         context: ExecutionContext,
@@ -47,15 +47,15 @@ class DefaultOnlineNode(OnlineNode[NT, NodeDataT], ABC, Generic[NT, NodeDataT]):
         if batch_size == 0:
             return []
 
-        parent_results = self.evaluate_parents(self.parents, parsed_schemas, context, online_entity_cache)
+        parent_results = await self.evaluate_parents(self.parents, parsed_schemas, context, online_entity_cache)
         main_inputs: list[ParentResults] = [
             {node: result.main for node, result in parent_result.items()} for parent_result in parent_results
         ]
 
         mains: list[SingleEvaluationResult] = self._get_single_evaluation_results(
-            self._evaluate_single_with_fallback(parsed_schemas, context, main_inputs, online_entity_cache)
+            await self._evaluate_single_with_fallback(parsed_schemas, context, main_inputs, online_entity_cache)
         )
-        chunk_results_per_parsed_schema: list[list[NodeDataT]] = self.__get_chunk_results_per_parsed_schema(
+        chunk_results_per_parsed_schema: list[list[NodeDataT]] = await self.__get_chunk_results_per_parsed_schema(
             parsed_schemas, context, parent_results, online_entity_cache
         )
         return [
@@ -69,7 +69,7 @@ class DefaultOnlineNode(OnlineNode[NT, NodeDataT], ABC, Generic[NT, NodeDataT]):
             for i in range(batch_size)
         ]
 
-    def __get_chunk_results_per_parsed_schema(
+    async def __get_chunk_results_per_parsed_schema(
         self,
         parsed_schemas: Sequence[ParsedSchema],
         context: ExecutionContext,
@@ -91,7 +91,7 @@ class DefaultOnlineNode(OnlineNode[NT, NodeDataT], ABC, Generic[NT, NodeDataT]):
             chunked_batched_parent_results: list[ParentResults] = [
                 batched_input.input_ for batched_input in batched_inputs
             ]
-            batch_results = self._evaluate_single_with_fallback(
+            batch_results = await self._evaluate_single_with_fallback(
                 parsed_schemas, context, chunked_batched_parent_results, online_entity_cache
             )
 
@@ -142,34 +142,34 @@ class DefaultOnlineNode(OnlineNode[NT, NodeDataT], ABC, Generic[NT, NodeDataT]):
         input_parent_results[chunked_parent] = chunked_result
         return input_parent_results
 
-    def _evaluate_single_with_fallback(
+    async def _evaluate_single_with_fallback(
         self,
         parsed_schemas: Sequence[ParsedSchema],
         context: ExecutionContext,
         parent_results: Sequence[ParentResults],
         online_entity_cache: OnlineEntityCache,
     ) -> list[NodeDataT]:
-        single_results = self._evaluate_singles(parent_results, context)
+        single_results = await self._evaluate_singles(parent_results, context)
         parsed_schemas_with_none_result = [
             parsed_schemas[i] for i, single_result in enumerate(single_results) if single_result is None
         ]
-        default_results = deque(self.get_fallback_results(parsed_schemas_with_none_result, online_entity_cache))
+        default_results = deque(await self.get_fallback_results(parsed_schemas_with_none_result, online_entity_cache))
         results = [
             default_results.popleft() if single_result is None else single_result for single_result in single_results
         ]
         return results
 
     @abstractmethod
-    def _evaluate_singles(
+    async def _evaluate_singles(
         self,
         parent_results: Sequence[ParentResults],
         context: ExecutionContext,
     ) -> Sequence[NodeDataT | None]:
         pass
 
-    def get_fallback_results(
+    async def get_fallback_results(
         self,
         parsed_schemas: Sequence[ParsedSchema],
         online_entity_cache: OnlineEntityCache,
     ) -> list[NodeDataT]:
-        return self.load_stored_results_or_raise_exception(parsed_schemas, online_entity_cache)
+        return await self.load_stored_results_or_raise_exception(parsed_schemas, online_entity_cache)
