@@ -27,7 +27,6 @@ from superlinked.framework.common.transform.transform import Step
 from superlinked.framework.common.transform.transformation_factory import (
     TransformationFactory,
 )
-from superlinked.framework.common.util.async_util import AsyncUtil
 from superlinked.framework.online.dag.evaluation_result import EvaluationResult
 from superlinked.framework.online.dag.online_node import OnlineNode
 from superlinked.framework.online.online_entity_cache import OnlineEntityCache
@@ -40,7 +39,7 @@ class OnlineCustomVectorEmbeddingNode(OnlineNode[CustomVectorEmbeddingNode, Vect
         parents: list[OnlineNode],
     ) -> None:
         super().__init__(node, parents)
-        self._embedding_transformation = TransformationFactory.create_embedding_transformation(
+        self._embedding_transformation = TransformationFactory.create_multi_embedding_transformation(
             self.node.transformation_config
         )
 
@@ -50,37 +49,43 @@ class OnlineCustomVectorEmbeddingNode(OnlineNode[CustomVectorEmbeddingNode, Vect
         return self.node.length
 
     @property
-    def embedding_transformation(self) -> Step[Vector, Vector]:
+    def embedding_transformation(self) -> Step[Sequence[Vector], list[Vector]]:
         return self._embedding_transformation
 
     @override
-    def evaluate_self(
+    async def evaluate_self(
         self,
         parsed_schemas: Sequence[ParsedSchema],
         context: ExecutionContext,
         online_entity_cache: OnlineEntityCache,
     ) -> list[EvaluationResult[Vector] | None]:
+        results = await self._calculate_results(parsed_schemas, context, online_entity_cache)
+        return [self._wrap_in_evaluation_result(result) for result in results]
+
+    async def _calculate_results(
+        self, parsed_schemas: Sequence[ParsedSchema], context: ExecutionContext, online_entity_cache: OnlineEntityCache
+    ) -> list[Vector]:
         if len(self.parents) == 0:
-            results = self.load_stored_results_with_default(
+            return await self.load_stored_results_with_default(
                 [(parsed_schema.schema, parsed_schema.id_) for parsed_schema in parsed_schemas],
                 Vector.init_zero_vector(self.node.length),
                 online_entity_cache,
             )
-        else:
-            parent_results = self.evaluate_parent(self.parents[0], parsed_schemas, context, online_entity_cache)
-            results = [self._evaluate_parent_result(parent_result, context) for parent_result in parent_results]
-        return [self._wrap_in_evaluation_result(result) for result in results]
+        return await self._evaluate_multiple(parsed_schemas, context, online_entity_cache)
 
-    def _evaluate_parent_result(
-        self,
-        parent_result: EvaluationResult | None,
-        context: ExecutionContext,
-    ) -> Vector:
+    async def _evaluate_multiple(
+        self, parsed_schemas: Sequence[ParsedSchema], context: ExecutionContext, online_entity_cache: OnlineEntityCache
+    ) -> list[Vector]:
+        parent_results = await self.evaluate_parent(self.parents[0], parsed_schemas, context, online_entity_cache)
+        vectors = [self._prepare_parent_result(parent_result) for parent_result in parent_results]
+        return await self.embedding_transformation.transform(vectors, context)
+
+    def _prepare_parent_result(self, parent_result: EvaluationResult | None) -> Vector:
         if parent_result is None:
             return Vector.init_zero_vector(self.length)
         input_value = parent_result.main.value
         self._validate_input_value(input_value)
-        return AsyncUtil.run(self.embedding_transformation.transform(Vector(input_value), context))
+        return Vector(input_value)
 
     def _validate_input_value(self, input_value: Sequence[float]) -> None:
         if len(input_value) != self.length:
