@@ -69,11 +69,11 @@ class OnlineSchemaDag:
             raise InvalidStateException(f"{class_name} must have exactly one leaf Node.")
         if not isinstance(leaf_nodes[0], OnlineIndexNode):
             raise InvalidStateException(f"{class_name} must have a OnlineIndexNode leaf Node.")
-        root_node_schemas = set(
+        root_node_schemas = {
             cast(SchemaFieldNode, node.node).schema_field.schema_obj
             for node in nodes
             if isinstance(node, OnlineSchemaFieldNode)
-        )
+        }
         if len(root_node_schemas) != 1:
             raise InvalidStateException(f"{class_name}'s nodes must have the same root schema.")
         if schema not in root_node_schemas:
@@ -83,12 +83,12 @@ class OnlineSchemaDag:
                 root_schema_name=list(root_node_schemas)[0]._base_class_name,
             )
 
-    def evaluate(
+    async def evaluate(
         self,
         parsed_schemas: Sequence[ParsedSchema],
         context: ExecutionContext,
         online_entity_cache: OnlineEntityCache,
     ) -> list[EvaluationResult[Vector] | None]:
         with context.dag_output_recorder.visualize_dag_context(self.__base_nodes):
-            results = self.leaf_node.evaluate_next(parsed_schemas, context, online_entity_cache)
+            results = await self.leaf_node.evaluate_next(parsed_schemas, context, online_entity_cache)
         return results
