@@ -71,7 +71,7 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
         return mandatory_field_names_by_schema
 
     @override
-    def update(self, messages: Sequence[ParsedSchema]) -> None:
+    async def update(self, messages: Sequence[ParsedSchema]) -> None:
         """Process incoming messages and update vdb"""
 
         for message in messages:
@@ -94,7 +94,7 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
                     "schemas": list({msg.schema._schema_name for msg in regular_msgs}),
                 },
             ):
-                self.evaluator.evaluate(regular_msgs, self.context, online_entity_cache)
+                await self.evaluator.evaluate(regular_msgs, self.context, online_entity_cache)
         if event_msgs:
             with telemetry.span(
                 "processor.process.events",
@@ -103,7 +103,7 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
                     "schemas": list({msg.schema._schema_name for msg in event_msgs}),
                 },
             ):
-                self._process_events(event_msgs, online_entity_cache)
+                await self._process_events(event_msgs, online_entity_cache)
         with telemetry.span(
             "storage.write.fields",
             attributes={
@@ -112,17 +112,12 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
                 "schemas": list({msg.schema._schema_name for msg in regular_msgs}),
             },
         ):
-            self.storage_manager.write_combined_ingestion_result(
+            await self.storage_manager.write_combined_ingestion_result(
                 regular_msgs,
                 online_entity_cache.changes,
                 online_entity_cache.origin_ids,
                 self._index._fields_to_exclude,
             )
-        logger.info(
-            "stored input data",
-            schemas=list({parsed_schema.schema._schema_name for parsed_schema in messages}),
-            n_records=len(messages),
-        )
 
     def _validate_mandatory_fields_are_present(self, message: ParsedSchema) -> None:
         field_names = [field.schema_field.name for field in message.fields if field.value is not None]
@@ -137,23 +132,29 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
                 f"Message with id '{message.id_}' is missing mandatory index fields: {missing_fields_text}."
             )
 
-    def _process_events(
+    async def _process_events(
         self, event_parsed_schemas: Sequence[EventParsedSchema], online_entity_cache: OnlineEntityCache
     ) -> None:
         effect_to_parsed_schemas = self._map_effect_to_parsed_schemas(event_parsed_schemas)
         effect_group_to_parsed_schemas = self._map_effect_group_to_parsed_schemas(effect_to_parsed_schemas)
-        self.evaluator.evaluate_by_dag_effect_group(effect_group_to_parsed_schemas, self.context, online_entity_cache)
+        await self.evaluator.evaluate_by_dag_effect_group(
+            effect_group_to_parsed_schemas, self.context, online_entity_cache
+        )
 
     def _map_effect_to_parsed_schemas(
         self, event_parsed_schemas: Sequence[EventParsedSchema]
     ) -> dict[DagEffect, list[ParsedSchemaWithEvent]]:
         effect_to_parsed_schemas: dict[DagEffect, list[ParsedSchemaWithEvent]] = defaultdict(list)
         for event_parsed_schema in event_parsed_schemas:
+            covered_affected_schemas: set[ResolvedSchemaReference] = set()
             for effect in self._get_matching_effects(event_parsed_schema):
+                if effect.resolved_affected_schema_reference in covered_affected_schemas:
+                    continue
                 if schema_with_event := self._create_parsed_schema_with_event(
                     effect.resolved_affected_schema_reference, event_parsed_schema
                 ):
                     effect_to_parsed_schemas[effect].append(schema_with_event)
+                    covered_affected_schemas.add(effect.resolved_affected_schema_reference)
         return dict(effect_to_parsed_schemas)
 
     def _get_matching_effects(self, event_schema: EventParsedSchema) -> list[DagEffect]:
