@@ -77,8 +77,7 @@ class RedisFieldEncoder:
         return self._encode_vector(Vector(float_list))
 
     def _decode_float_list(self, float_list: bytes) -> list[float]:
-        vector = self._decode_vector(float_list)
-        return [float(x) for x in vector.value.tolist()]
+        return self._decode_vector(float_list).to_list()
 
     def _encode_int(self, int_: int) -> int:
         return int_
